@@ -5,6 +5,10 @@ then
     # for Mac OSX
     unset CC
     unset CXX
+    unset FC
+    unset F77
+    unset F90
+    unset F95
     unset MACOSX_VERSION_MIN
     unset MACOSX_DEPLOYMENT_TARGET
     unset CMAKE_OSX_DEPLOYMENT_TARGET
@@ -17,6 +21,10 @@ then
     # for Linux
     unset CC
     unset CXX
+    unset FC
+    unset F77
+    unset F90
+    unset F95
     unset CFLAGS
     unset CXXFLAGS
     unset LDFLAGS
